Learn R Programming

bpvars (version 1.0)

country_grouping_incomegroup: A vector with country grouping by income group for 189 countries

Description

Each of the country is classified into one of the 4 categories according to their geographical location. The categories are:

1

Low-income countries

2

Lower-middle-income countries

3

Upper-middle-income countries

4

High-income countries

Last data update was implemented on 2025-09-26.

Usage

data(country_grouping_incomegroup)

Arguments

Format

A numeric vector with values from 1 to 4

Examples

Run this code
data(country_grouping_incomegroup)   # upload the data

# setup a fixed group allocation Panel VAR model
spec = specify_bvarGroupPANEL$new(
         ilo_dynamic_panel,
         group_allocation = country_grouping_incomegroup
)

Run the code above in your browser using DataLab