ilo_exogenous_forecasts: Data containing future observations for 189 countries
from 2025 to 2027 to be used to forecast with models with
ilo_exogenous_variables
Description
For each of the countries a time series of 3 observations on
On the dummies is provided. These future values are all equal to zero. They
provide benchmark for the objects to be used when exogenous_variables
are used.
Last data update was implemented on 2026-04-18.
Usage
data(ilo_exogenous_forecasts)
Arguments
Format
A list of 189 ts objects with time series of 3 observations
on 3 variables: