specify_posterior_bvarGroupPriorPANEL: R6 Class Representing PosteriorBVARGROUPPRIORPANEL
Description
The class PosteriorBVARGROUPPRIORPANEL contains posterior output and the specification
including the last MCMC draw for the Bayesian Panel VAR model with country grouping.
Note that due to the thinning of the MCMC output the starting value in element
last_draw might not be equal to the last draw provided in
element posterior.
an object of class BVARGROUPPRIORPANEL with the last draw of the
current MCMC run as the starting value to be passed to the continuation
of the MCMC estimation using estimate().