Method new()
Create a new specification of the Bayesian Panel VAR model with country
grouping for global prior parameters BVARGROUPPRIORPANEL. The groups can be pre-specified,
which requires the argument group_allocation to be provided, or estimated,
which requires the argument G for the number of groups to be provided
and the argument group_allocation to be left empty.
Usage
specify_bvarGroupPriorPANEL$new(
data,
p = 1L,
exogenous = NULL,
stationary = rep(FALSE, ncol(data[[1]])),
type = rep("real", ncol(data[[1]])),
G = NULL,
group_allocation = NULL
)
Arguments
data
a list with C elements of (T_c+p)xN matrices
with time series data.
p
a positive integer providing model's autoregressive lag order.
exogenous
a (T+p)xd matrix of exogenous variables.
stationary
an N logical vector - its element set to
FALSE sets the prior mean for the autoregressive parameters of the
Nth equation to the white noise process, otherwise to random walk.
type
an N character vector with elements set to "rate" or "real"
determining the truncation of the predictive density to [0, 100] and
(-Inf, Inf) (no truncation) for each of the variables.
G
a positive integer specifying the number of country groups. Its
specification is required if group_allocation is not provided and
the country groups to be estimated.
group_allocation
an argument that can be provided as a numeric
vector with integer numbers denoting group allocations to pre-specify the
the country groups, in which case they are not estimated, or left empty
if the country groups are to be estimated.
Returns
A new complete specification for the Bayesian Panel VAR model BVARPANEL.
Method get_data_matrices()
Returns the data matrices as the DataMatricesBVARPANEL object.
Usage
specify_bvarGroupPriorPANEL$get_data_matrices()
Examples
spec = specify_bvarPANEL$new(
data = ilo_dynamic_panel
)
spec$get_data_matrices()
Method get_prior()
Returns the prior specification as the PriorBVARPANEL object.
Usage
specify_bvarGroupPriorPANEL$get_prior()
Examples
spec = specify_bvarPANEL$new(
data = ilo_dynamic_panel
)
spec$get_prior()
Method get_starting_values()
Returns the starting values as the StartingValuesBVARPANEL object.
Usage
specify_bvarGroupPriorPANEL$get_starting_values()
Examples
spec = specify_bvarPANEL$new(
data = ilo_dynamic_panel
)
spec$get_starting_values()
Method get_type()
Returns the type of the model.
Usage
specify_bvarGroupPriorPANEL$get_type()
Examples
spec = specify_bvarPANEL$new(
data = ilo_dynamic_panel
)
spec$get_type()
Method set_global2pooled()
Sets the prior mean of the global autoregressive parameters to the OLS
pooled panel estimator following Zellner, Hong (1989).
Usage
specify_bvarGroupPriorPANEL$set_global2pooled(x)
Arguments
x
a vector of four values setting the adaptive MH sampler for nu:
adaptive rate, target acceptance rate, the iteration at which to
start adapting, the initial scaling rate
Examples
spec = specify_bvarPANEL$new(
data = ilo_dynamic_panel
)
spec$set_global2pooled()
Method set_adaptiveMH()
Sets the parameters of adaptive Metropolis-Hastings sampler for the parameter nu.
Usage
specify_bvarGroupPriorPANEL$set_adaptiveMH(x)
Arguments
x
a vector of four values setting the adaptive MH sampler for nu:
adaptive rate, target acceptance rate, the iteration at which to
start adapting, the initial scaling rate
Examples
spec = specify_bvarPANEL$new(
data = ilo_dynamic_panel[1:5]
)
spec$set_adaptiveMH(c(0.6, 0.4, 10, 0.1))
Method clone()
The objects of this class are cloneable with this method.
Usage
specify_bvarGroupPriorPANEL$clone(deep = FALSE)
Arguments
deep
Whether to make a deep clone.