M
an KxN matrix, the mean of the second-level MNIW prior
distribution for the global parameter matrices \(\mathbf{A}\)
and \(\mathbf{V}\)
W
a KxK column-specific covariance matrix of the second-level
MNIW prior distribution for the global parameter matrices \(\mathbf{A}\)
and \(\mathbf{V}\)
S_inv
an NxN row-specific precision matrix of the second-level
MNIW prior distribution for the global parameter matrices \(\mathbf{A}\)
and \(\mathbf{V}\)
S_Sigma_inv
an NxN precision matrix of the second-level
Wishart prior distribution for the global parameter matrix \(\mathbf{\Sigma}\).
eta
a positive shape parameter of the second-level MNIW prior distribution
for the global parameter matrices \(\mathbf{A}\)
and \(\mathbf{V}\)
mu_Sigma
a positive shape parameter of the second-level Wishart prior
distribution for the global parameter matrix \(\mathbf{\Sigma}\).
lambda
a positive shape of the second-level exp prior distribution
for the shape parameter \(\nu\).
mu_m
a scalar mean of the third-level normal prior distribution
for the global average persistence parameter \(m\).
sigma2_m
a positive scalar variance of the third-level normal prior
distribution for the global average persistence parameter \(m\).
s_w
a positive scalar scale of the third-level gamma prior
distribution for parameter \(w\).
a_w
a positive scalar shape of the third-level gamma prior
distribution for parameter \(w\).
s_s
a positive scalar scale parameter of the third-level
inverted-gamma 2 prior distribution for parameter \(s\).
nu_s
a positive scalar shape parameter of the third-level
inverted-gamma 2 prior distribution for parameter \(s\).