Learn R Programming

bpvars (version 1.0)

summary.PosteriorBVARGROUPPRIORPANEL: Provides posterior estimation summary for Bayesian Hierarchical Panel Vector Autoregressions with group-specific global prior

Description

Provides posterior mean, standard deviations, as well as 5 and 95 percentiles of the parameters for all C countries.

Usage

# S3 method for PosteriorBVARGROUPPRIORPANEL
summary(object, ...)

Value

A list reporting the posterior mean, standard deviations, as well as 5 and 95 percentiles of the country-specific parameters.

Arguments

object

an object of class PosteriorBVARGROUPPRIORPANEL obtained using the estimate() function applied to Vector Autoregressions containing draws from the posterior distribution of the parameters.

...

additional arguments affecting the summary produced.

Author

Tomasz Woźniak wozniak.tom@pm.me

See Also

estimate.BVARGROUPPRIORPANEL, specify_bvarGroupPriorPANEL

Examples

Run this code
# specify the model
specification = specify_bvarGroupPriorPANEL$new(
      data = ilo_dynamic_panel[1:5],
      group_allocation = country_grouping_region[1:5]
)
burn_in       = estimate(specification, 5)             # run the burn-in
posterior     = estimate(burn_in, 5)                   # estimate the model
summary(posterior)

Run the code above in your browser using DataLab