Learn R Programming

bpvars (version 1.0)

summary.PosteriorFEVDPANEL: Provides posterior summary of forecast error variance decompositions

Description

Provides posterior means of the forecast error variance decompositions of each variable at all horizons.

Usage

# S3 method for PosteriorFEVDPANEL
summary(object, which_c, ...)

Value

A list reporting the posterior mean of the forecast error variance decompositions of each variable at all horizons.

Arguments

object

an object of class PosteriorFEVDPANEL obtained using the compute_variance_decompositions() function containing draws from the posterior distribution of the forecast error variance decompositions.

which_c

a positive integer or a character string specifying the country for which the forecast should be plotted.

...

additional arguments affecting the summary produced.

Author

Tomasz Woźniak wozniak.tom@pm.me

See Also

compute_variance_decompositions.PosteriorBVARPANEL, plot

Examples

Run this code
# specify the model and set seed
specification  = specify_bvarPANEL$new(ilo_dynamic_panel[1:5], p = 1)

# run the burn-in
burn_in        = estimate(specification, 5)

# estimate the model
posterior      = estimate(burn_in, 5)

# compute forecast error variance decomposition 4 years ahead
fevd           = compute_variance_decompositions(posterior, horizon = 4)
summary(fevd, which_c = "ARG")

Run the code above in your browser using DataLab